==> dagster-1.8.12.tar.gz: dagster-1.8.12/dagster/_core/workspace/workspace.py <==
from enum import Enum
from functools import cached_property
from typing import TYPE_CHECKING, Mapping, Optional

from typing_extensions import Annotated

from dagster._record import ImportFrom, record
from dagster._utils.error import SerializableErrorInfo

if TYPE_CHECKING:
    from dagster._core.definitions.remote_asset_graph import RemoteAssetGraph
    from dagster._core.remote_representation import CodeLocation, CodeLocationOrigin


# For locations that are loaded asynchronously
class CodeLocationLoadStatus(Enum):
    LOADING = "LOADING"  # Waiting for location to load or update
    LOADED = "LOADED"  # Finished loading (may be an error)


@record
class CodeLocationEntry:
    origin: Annotated["CodeLocationOrigin", ImportFrom("dagster._core.remote_representation")]
    code_location: Optional[
        Annotated["CodeLocation", ImportFrom("dagster._core.remote_representation")]
    ]
    load_error: Optional[SerializableErrorInfo]
    load_status: CodeLocationLoadStatus
    display_metadata: Mapping[str, str]
    update_timestamp: float
    version_key: str


@record
class CodeLocationStatusEntry:
    """Slimmer version of WorkspaceLocationEntry, containing the minimum set of information required
    to know whether the workspace needs reloading.
    """

    location_name: str
    load_status: CodeLocationLoadStatus
    update_timestamp: float
    version_key: str


@record
class WorkspaceSnapshot:
    code_location_entries: Mapping[str, CodeLocationEntry]

    @cached_property
    def asset_graph(self) -> "RemoteAssetGraph":
        from dagster._core.definitions.remote_asset_graph import RemoteAssetGraph

        return RemoteAssetGraph.from_workspace_snapshot(self)

    def with_code_location(self, name: str, entry: CodeLocationEntry) -> "WorkspaceSnapshot":
        return WorkspaceSnapshot(code_location_entries={**self.code_location_entries, name: entry})


def location_status_from_location_entry(
    entry: CodeLocationEntry,
) -> CodeLocationStatusEntry:
    return CodeLocationStatusEntry(
        location_name=entry.origin.location_name,
        load_status=entry.load_status,
        update_timestamp=entry.update_timestamp,
        version_key=entry.version_key,
    )

==> dagster-1.9.4.tar.gz: dagster-1.9.4/dagster/_core/workspace/workspace.py <==
from enum import Enum
from functools import cached_property
from typing import TYPE_CHECKING, Mapping, Optional

from typing_extensions import Annotated

from dagster._record import ImportFrom, record
from dagster._utils.error import SerializableErrorInfo

if TYPE_CHECKING:
    from dagster._core.definitions.remote_asset_graph import RemoteWorkspaceAssetGraph
    from dagster._core.remote_representation import CodeLocation, CodeLocationOrigin


# For locations that are loaded asynchronously
class CodeLocationLoadStatus(Enum):
    LOADING = "LOADING"  # Waiting for location to load or update
    LOADED = "LOADED"  # Finished loading (may be an error)


@record
class CodeLocationEntry:
    origin: Annotated["CodeLocationOrigin", ImportFrom("dagster._core.remote_representation")]
    code_location: Optional[
        Annotated["CodeLocation", ImportFrom("dagster._core.remote_representation")]
    ]
    load_error: Optional[SerializableErrorInfo]
    load_status: CodeLocationLoadStatus
    display_metadata: Mapping[str, str]
    update_timestamp: float
    version_key: str


@record
class CodeLocationStatusEntry:
    """Slimmer version of WorkspaceLocationEntry, containing the minimum set of information required
    to know whether the workspace needs reloading.
    """

    location_name: str
    load_status: CodeLocationLoadStatus
    update_timestamp: float
    version_key: str


@record
class WorkspaceSnapshot:
    code_location_entries: Mapping[str, CodeLocationEntry]

    @cached_property
    def asset_graph(self) -> "RemoteWorkspaceAssetGraph":
        from dagster._core.definitions.remote_asset_graph import RemoteWorkspaceAssetGraph

        return RemoteWorkspaceAssetGraph.build(self)

    def with_code_location(self, name: str, entry: CodeLocationEntry) -> "WorkspaceSnapshot":
        return WorkspaceSnapshot(code_location_entries={**self.code_location_entries, name: entry})


def location_status_from_location_entry(
    entry: CodeLocationEntry,
) -> CodeLocationStatusEntry:
    return CodeLocationStatusEntry(
        location_name=entry.origin.location_name,
        load_status=entry.load_status,
        update_timestamp=entry.update_timestamp,
        version_key=entry.version_key,
    )
